summaryrefslogtreecommitdiffstats
path: root/src/include/usr/hwas/common
diff options
context:
space:
mode:
authorKumar Challa <kvchalla@us.ibm.com>2013-04-24 12:42:20 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2013-05-13 10:57:58 -0500
commita212ae0c61e46778897de05cdd4183cc69b1c76c (patch)
treee1876bbf6dcba86027a35f9c5c14de5cde1fd2b8 /src/include/usr/hwas/common
parent6d1c81fcc5b8f48d2456e5f1f276997ee8527b68 (diff)
downloadtalos-hostboot-a212ae0c61e46778897de05cdd4183cc69b1c76c.tar.gz
talos-hostboot-a212ae0c61e46778897de05cdd4183cc69b1c76c.zip
Do not deconfigTarget when System is at runtime.
Change-Id: I4daa3c3370eb91cdc5676e315a1476ed8c3a2e2a RTC:45747 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/4195 Tested-by: Jenkins Server Reviewed-by: MIKE J. JONES <mjjones@us.ibm.com> Reviewed-by: Brian H. Horton <brianh@linux.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/include/usr/hwas/common')
-rw-r--r--src/include/usr/hwas/common/deconfigGard.H7
-rw-r--r--src/include/usr/hwas/common/hwasCommon.H12
2 files changed, 14 insertions, 5 deletions
diff --git a/src/include/usr/hwas/common/deconfigGard.H b/src/include/usr/hwas/common/deconfigGard.H
index b0e793f2a..f2f41c0bd 100644
--- a/src/include/usr/hwas/common/deconfigGard.H
+++ b/src/include/usr/hwas/common/deconfigGard.H
@@ -190,15 +190,16 @@ public:
* Deconfigure actions and create a Deconfigure Record) and Deconfigure
* Targets by association. Any errors deconfiguring targets are committed
* and the function continues. The only errors returned are usage errors.
+ * By default, targets are NOT deconfigured if the system is at Runtime.
*
* @param[in] i_target Reference to Target to deconfigure.
* @param[in] i_errlPlid Error log PLID to store in Deconfigure Record.
- *
+ * @param[in] i_evenAtRunTime Deconfigure even if at RunTime
* @return errlHndl_t. Error log handle.
*/
errlHndl_t deconfigureTarget(TARGETING::Target & i_target,
- const uint32_t i_errlPlid);
-
+ const uint32_t i_errlPlid,
+ bool i_evenAtRunTime = false);
/**
* @brief Registers a Delayed Deconfigure
*
diff --git a/src/include/usr/hwas/common/hwasCommon.H b/src/include/usr/hwas/common/hwasCommon.H
index 29d240238..ae0c52ac6 100644
--- a/src/include/usr/hwas/common/hwasCommon.H
+++ b/src/include/usr/hwas/common/hwasCommon.H
@@ -51,11 +51,19 @@ namespace HWAS
{
/**
- * @brief platform specific code to determine if the targets in the
+ * @brief platform specific code to determine whether the System is at runtime.
+ *
+ * @return bool Return true if the System is at runtime; false if not.
+ */
+
+bool platSystemIsAtRuntime();
+
+/**
+ *@brief platform specific code to determine if the targets in the
* input list are present or not. If the target is NOT present,
* target should be erased from the list
*
- * @param[in] io_targets TargetHandleList of targets to check for presence
+ *@param[in] io_targets TargetHandleList of targets to check for presence
*
* @return errlHndl_t valid errlHndl_t handle if there was an error
* NULL if no errors;
OpenPOWER on IntegriCloud